import { useSelector } from "react-redux";
import { AppState } from "@/state/reducer";
import { getSubmissionStatus, SubmissionState, SubmissionStatus } from "@/state/reducer/submission";
import { useTranslation } from "react-i18next";
import { Box, Button, ButtonProps, StepProps } from "@material-ui/core";
import { FileUploadOutline } from "mdi-material-ui/index";
import { route } from "@/routing";
import { Link as RouterLink } from "react-router-dom";
import { Actions, Step } from "@/components";
import React, { HTMLProps } from "react";
import { Alert, AlertTitle } from "@material-ui/lab";
import { ContactButton, Status } from "@/pages/steps/common";
import { useCurrentEdition, useDeadlines } from "@/hooks";
import { useSpacing } from "@/styles";

const ReportActions = () => {
    const status = useSelector<AppState, SubmissionStatus>(state => getSubmissionStatus(state.report));

    const { t } = useTranslation();

    const FormAction = ({ children = t('steps.report.submit'), ...props }: ButtonProps) =>
        <Button to={ route("internship_report") } variant="contained" color="primary" component={ RouterLink } startIcon={ <FileUploadOutline /> } { ...props as any }>
            { children }
        </Button>

    switch (status) {
        case "awaiting":
            return <Actions>
            </Actions>
        case "accepted":
            return <Actions>
                <FormAction variant="outlined" color="secondary">{ t('send-again') }</FormAction>
            </Actions>
        case "declined":
            return <Actions>
                <FormAction>{ t('send-again') }</FormAction>
                <ContactButton/>
            </Actions>
        case "draft":
            return <Actions>
                <FormAction />
            </Actions>

        default:
            return <Actions/>
    }
}

export const PlanComment = (props: HTMLProps<HTMLDivElement>) => {
    const { comment, declined } = useSelector<AppState, SubmissionState>(state => state.plan);
    const { t } = useTranslation();

    return comment ? <Alert severity={ declined ? "error" : "warning" } { ...props as any }>
        <AlertTitle>{ t('comments') }</AlertTitle>
        { comment }
    </Alert> : null
}

export const ReportStep = (props: StepProps) => {
    const { t } = useTranslation();

    const submission = useSelector<AppState, SubmissionState>(state => state.report);
    const spacing = useSpacing(2);
    const edition = useCurrentEdition();

    const status = getSubmissionStatus(submission);
    const deadlines = useDeadlines();

    const { sent, declined, comment } = submission;

    return <Step { ...props }
                 label={ t('steps.report.header') }
                 active={ true } completed={ sent } declined={ declined } waiting={ status == "awaiting" }
                 until={ deadlines.report }
                 notBefore={ edition?.reportingStart }
                 state={ <Status submission={ submission } /> }>
        <div className={ spacing.vertical }>
            <p>{ t(`steps.report.info.${ status }`) }</p>

            { comment && <Box pb={ 2 }><PlanComment/></Box> }

            <ReportActions/>
        </div>
    </Step>;
}
